#
# Copyright (c) 2008-2018 Thierry Florac <tflorac AT ulthar.net>
# All Rights Reserved.
#
# This software is subject to the provisions of the Zope Public License,
# Version 2.1 (ZPL).  A copy of the ZPL should accompany this distribution.
# THIS SOFTWARE IS PROVIDED "AS IS" AND ANY AND ALL EXPRESS OR IMPLIED
# WARRANTIES ARE DISCLAIMED, INCLUDING, BUT NOT LIMITED TO, THE IMPLIED
# WARRANTIES OF TITLE, MERCHANTABILITY, AGAINST INFRINGEMENT, AND FITNESS
# FOR A PARTICULAR PURPOSE.
#

__docformat__ = 'restructuredtext'

from zope.interface import implementer

from pyams_file.interfaces import IImage, IMediaWidget, IThumbnailForm
from pyams_file.zmi import FileModifierAction
from pyams_file.zmi.image import ImageSelectionThumbnailEditForm
from pyams_form.form import ajax_config
from pyams_form.help import FormHelp
from pyams_form.interfaces.form import IFormHelp
from pyams_pagelet.pagelet import pagelet_config
from pyams_skin.interfaces.viewlet import IContextActions
from pyams_skin.layer import IPyAMSLayer
from pyams_utils.adapter import adapter_config
from pyams_utils.interfaces import VIEW_PERMISSION
from pyams_utils.url import absolute_url
from pyams_viewlet.viewlet import viewlet_config
from pyams_zmi.layer import IAdminLayer

from onf_website import _


#
# Image banner thumbnail selection
#

@viewlet_config(name='image.thumb.banner.action', context=IImage, layer=IAdminLayer, view=IMediaWidget,
                manager=IContextActions, weight=70)
class ImageBannerThumbnailAction(FileModifierAction):
    """Banner thumbnail image selection"""

    _label = _("Select banner thumbnail...")

    @property
    def label(self):
        return '<div>{label}</div><div class="padding-y-5"><img src="{url}/++thumb++banner:200x128?_=" ' \
               '/></div>'.format(label=self.request.localizer.translate(self._label),
                                 url=absolute_url(self.context, self.request))

    label_css_class = 'fa fa-fw-md fa-window-minimize fa-rotate-180'

    url = 'banner-thumbnail.html'
    modal_target = True


@pagelet_config(name='banner-thumbnail.html', context=IImage, layer=IPyAMSLayer, permission=VIEW_PERMISSION)
@ajax_config(name='banner-thumbnail.json', context=IImage, layer=IPyAMSLayer, permission=VIEW_PERMISSION)
@implementer(IThumbnailForm)
class ImageBannerThumbnailEditForm(ImageSelectionThumbnailEditForm):
    """Image banner thumbnail edit form"""

    prefix = 'image_banner.'

    legend = _("Select banner thumbnail")
    icon_css_class = 'fa fa-fw fa-window-minimize fa-rotate-180'

    selection_name = 'banner'
    selection_ratio = '5:1'


@adapter_config(context=(IImage, IAdminLayer, ImageBannerThumbnailEditForm), provides=IFormHelp)
class ImageBannerThumbnailEditFormHelpAdapter(FormHelp):
    """Banner image thumbnail edit form help adapter"""

    message = _("""You can use this form to select a banner thumbnail of this image.

**WARNING**: cropping or resizing an image will reset all selected thumbnails and adaptive images!!""")
    message_format = 'rest'
